/*
 *  FilesPaths.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL, version 2
 */


using System;
using System.IO;


namespace Incollector.Engine {

	/// <summary>Paths to Incollector files and directories.</summary>
	public static class FilesPaths {
		/// <summary>Returns true, if using operating system is Windows.</summary>
		public static bool IsWinSystem ()
		{
			if ((Environment.OSVersion.Platform == PlatformID.Win32NT) ||
				    	(Environment.OSVersion.Platform == PlatformID.Win32S) ||
					    (Environment.OSVersion.Platform == PlatformID.Win32Windows) ||
					    (Environment.OSVersion.Platform == PlatformID.WinCE))
				return true;
			else
				return false;
		}
		
		
		/// <summary>Returns home directory path.</summary>
		public static string HomeDirectory {
			get {
				if (IsWinSystem ())
					return Environment.GetEnvironmentVariable ("USERPROFILE");
				else
					return Environment.GetEnvironmentVariable ("HOME");
			}
		}
		

		/// <summary>Returns incollector folder.</summary>
		public static string Directory {
			get {
				if (IsWinSystem ())
					return "incollector";
				else
					return ".incollector";
			}
		}
		
		
		/// <summary>Returns path to database file.</summary>
		public static string DBFile {
			get { return HomeDirectory + Separator + Directory + Separator + "data.inr"; }
		}
		
		
		/// <summary>Returns path to autosave database file.</summary>
		public static string DBSavingFile {
			get { return HomeDirectory + Separator + Directory + Separator + "data.inr.saving"; }
		}
		
		
		/// <summary>Returns separator in paths.</summary>
		public static char Separator {
			get {
				if (IsWinSystem ())
					return '\\';
				else
					return '/';
			}
		}
		
		
		/// <summary>Returns path to settings file</summary>
		public static string SettingsFile {
			get { return HomeDirectory + Separator + Directory + Separator + "settings.inr"; }
		}
		
		
		/// <summary>Returns path to autosave settings file</summary>
		public static string SettingsSavingFile {
			get { return HomeDirectory + Separator + Directory + Separator + "settings.inr.saving"; }
		}
		
		
		/// <summary>Returns path to global (system) plugins directory</summary>
		/// <remarks>Usually /$LD_LIBRARY_PATH/incollector/plugins (i.e. /usr/lib/incollector/plugins)</remarks>
		public static string GlobalPluginsDirectory {
			get { return Path.Combine (System.AppDomain.CurrentDomain.BaseDirectory, "plugins"); }
		}
		
		
		/// <summary>Returns user plugin directory</summary>
		/// <remarks>Usually $HOME/.incollector/plugins</remarks>
		public static string UserPluginsDirectory {
			get { return HomeDirectory + Separator + Directory + Separator + "plugins"; }
		}
		
		
		/// <summary>Returns path to search folders file</summary>
		public static string SearchFoldersFile {
			get { return HomeDirectory + Separator + Directory + Separator + "search_folders.xml"; }
		}
		
		/// <summary>Returns path to search folders saving file</summary>
		public static string SearchFoldersSavingFile {
			get { return HomeDirectory + Separator + Directory + Separator + "search_folders.xml.saving"; }
		}


		/// <summary>Returns true, if settings file exists</summary>
		public static bool SettingsFileExists {
			get { return System.IO.File.Exists (SettingsFile); }
		}
		
		
		/// <summary>Creates $HOME/.incollector directory (if it doesn't exists)</summary>
		public static void CheckHomeDir ()
		{
			if (!System.IO.Directory.Exists (HomeDirectory + Separator + Directory))
				System.IO.Directory.CreateDirectory (HomeDirectory + Separator + Directory);
		}
		
		public static void MoveSavings ()
		{
			if (File.Exists(FilesPaths.SettingsSavingFile) == true) {
				try {
					File.Delete(FilesPaths.SettingsFile);
				} finally {
					File.Move(FilesPaths.SettingsSavingFile, FilesPaths.SettingsFile);
				}
			}
			
			if (File.Exists(FilesPaths.DBSavingFile) == true) {
				try {
					File.Delete(FilesPaths.DBFile);
				} finally {
					File.Move(FilesPaths.DBSavingFile, FilesPaths.DBFile);
				}
			}
			
			if (File.Exists(FilesPaths.SearchFoldersSavingFile) == true) {
				try {
					File.Delete(FilesPaths.SearchFoldersFile);
				} finally {
					File.Move(FilesPaths.SearchFoldersSavingFile, FilesPaths.SearchFoldersFile);
				}
			}
		}
	}
}
